@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 extends 'Zing::Kernel';
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 # ATTRIBUTES
 
@@ -196,7 +196,7 @@ L<Zing::Data>: Process Data
 
 =item *
 
-L<Zing::Domain>: Aggregate Root
+L<Zing::Domain>: Shared State Management
 
 =item *
 
