@@ -13,7 +13,7 @@ use Data::Object::ClassHas;
 
 use Zing::Channel;
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 # ATTRIBUTES
 
@@ -36,7 +36,9 @@ fun new_channel($self) {
 # BUILDERS
 
 fun BUILD($self) {
-  return $self->apply if $self->channel->reset;
+  $self->channel->{cursor}-- if $self->channel->{cursor};
+
+  return $self->apply;
 }
 
 # SHIMS
@@ -69,42 +71,42 @@ sub _copy {
 # METHODS
 
 method apply() {
-  undef $self->{data} if $self->channel->renew;
+  undef $self->{state} if $self->channel->renew;
 
   while (my $data = $self->recv) {
     my $op = $data->{op};
     my $key = $data->{key};
     my $val = $data->{val};
 
-    if ($data->{snapshot} && !$self->{data}) {
-      $self->{data} = _copy($data->{snapshot});
+    if ($data->{snapshot} && !$self->{state}) {
+      $self->{state} = _copy($data->{snapshot});
     }
 
     local $@;
 
     if ($op eq 'decr') {
-      eval{($self->data->{$key} //= 0) -= ($val->[0] // 0)};
+      eval{($self->state->{$key} //= 0) -= ($val->[0] // 0)};
     }
     elsif ($op eq 'del') {
-      eval{CORE::delete $self->data->{$key}};
+      eval{CORE::delete $self->state->{$key}};
     }
     elsif ($op eq 'incr') {
-      eval{($self->data->{$key} //= 0 ) += ($val->[0] // 0)};
+      eval{($self->state->{$key} //= 0 ) += ($val->[0] // 0)};
     }
     elsif ($op eq 'pop') {
-      eval{CORE::pop @{$self->data->{$key}}};
+      eval{CORE::pop @{$self->state->{$key}}};
     }
     elsif ($op eq 'push') {
-      eval{CORE::push @{$self->data->{$key}}, @$val};
+      eval{CORE::push @{$self->state->{$key}}, @$val};
     }
     elsif ($op eq 'set') {
-      eval{$self->data->{$key} = $val->[0]};
+      eval{$self->state->{$key} = $val->[0]};
     }
     elsif ($op eq 'shift') {
-      eval{CORE::shift @{$self->data->{$key}}};
+      eval{CORE::shift @{$self->state->{$key}}};
     }
     elsif ($op eq 'unshift') {
-      eval{CORE::unshift @{$self->data->{$key}}, @$val};
+      eval{CORE::unshift @{$self->state->{$key}}, @$val};
     }
   }
 
@@ -114,7 +116,7 @@ method apply() {
 method change(Str $op, Str $key, Any @val) {
   my %fields = (
     key => $key,
-    snapshot => _copy($self->data),
+    snapshot => _copy($self->state),
     time => time,
     val => [@val],
   );
@@ -150,12 +152,8 @@ method change(Str $op, Str $key, Any @val) {
   return $self->apply;
 }
 
-method data() {
-  return $self->{data} ||= {};
-}
-
 method get(Str $key) {
-  return $self->apply->data->{$key};
+  return $self->apply->state->{$key};
 }
 
 method decr(Str $key, Int $val = 1) {
@@ -194,6 +192,10 @@ method shift(Str $key) {
   return $self->apply->change('shift', $key);
 }
 
+method state() {
+  return $self->{state} ||= {};
+}
+
 method unshift(Str $key, Any @val) {
   return $self->apply->change('unshift', $key, @val);
 }
@@ -204,13 +206,13 @@ method unshift(Str $key, Any @val) {
 
 =head1 NAME
 
-Zing::Domain - Aggregate Root
+Zing::Domain - Shared State Management
 
 =cut
 
 =head1 ABSTRACT
 
-Aggregate Root Construct
+Shared State Management Construct
 
 =cut
 
@@ -305,24 +307,6 @@ method is used internally and shouldn't need to be called directly.
 
 =cut
 
-=head2 data
-
-  data() : HashRef
-
-The data method returns the raw aggregate data associated with the object.
-
-=over 4
-
-=item data example #1
-
-  # given: synopsis
-
-  $domain->data;
-
-=back
-
-=cut
-
 =head2 decr
 
   decr(Str $key, Int $val = 1) : Object
@@ -511,6 +495,24 @@ The shift method shifts data off of the stack associated with a specific key.
 
 =cut
 
+=head2 state
+
+  state() : HashRef
+
+The state method returns the raw aggregate data associated with the object.
+
+=over 4
+
+=item state example #1
+
+  # given: synopsis
+
+  $domain->state;
+
+=back
+
+=cut
+
 =head2 unshift
 
   unshift(Str $key, Any @val) : Object
