@@ -12,7 +12,7 @@ use Data::Object::Class;
 
 use Carp ();
 
-our $VERSION = '0.11'; # VERSION
+our $VERSION = '0.12'; # VERSION
 
 # METHODS
 
@@ -35,26 +35,30 @@ sub keys {
   Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "keys" not implemented);
 }
 
-sub pop {
-  Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "pop" not implemented);
-}
-
-sub pull {
-  Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "pull" not implemented);
-}
-
-sub push {
-  Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "push" not implemented);
-}
-
 sub load {
   Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "load" not implemented);
 }
 
+sub lpull {
+  Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "lpull" not implemented);
+}
+
+sub lpush {
+  Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "lpush" not implemented);
+}
+
 sub recv {
   Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "recv" not implemented);
 }
 
+sub rpull {
+  Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "rpull" not implemented);
+}
+
+sub rpush {
+  Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "rpush" not implemented);
+}
+
 sub send {
   Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "send" not implemented);
 }
@@ -71,7 +75,6 @@ sub term {
   shift; return join(':', @_);
 }
 
-
 sub test {
   Carp::croak qq(Error in Store: (@{[ref$_[0]]}) method "test" not implemented);
 }
@@ -239,80 +242,52 @@ hashref.
 
 =cut
 
-=head2 pop
+=head2 lpull
 
-  pop(Str $key) : Maybe[HashRef]
+  lpull(Str $key) : Maybe[HashRef]
 
-The pop method should pop data off of the bottom of a list in the datastore.
+The lpull method should pop data off of the top of a list in the datastore.
 
 =over 4
 
-=item pop example #1
+=item lpull example #1
 
   # given: synopsis
 
-  $store->pop('collection');
+  $store->lpull('collection');
 
 =back
 
 =over 4
 
-=item pop example #2
+=item lpull example #2
 
   # given: synopsis
 
-  # $store->push('collection', { status => 1 });
-  # $store->push('collection', { status => 2 });
+  # $store->rpush('collection', { status => 'ok' });
 
-  $store->pop('collection');
+  $store->lpull('collection');
 
 =back
 
 =cut
 
-=head2 pull
+=head2 lpush
 
-  pull(Str $key) : Maybe[HashRef]
+  lpush(Str $key) : Int
 
-The pull method should pop data off of the top of a list in the datastore.
+The lpush method should push data onto the top of a list in the datastore.
 
 =over 4
 
-=item pull example #1
+=item lpush example #1
 
   # given: synopsis
 
-  $store->pull('collection');
+  # $store->rpush('collection', { status => '1' });
+  # $store->rpush('collection', { status => '2' });
 
-=back
-
-=over 4
-
-=item pull example #2
-
-  # given: synopsis
-
-  # $store->push('collection', { status => 'ok' });
-
-  $store->pull('collection');
-
-=back
-
-=cut
-
-=head2 push
-
-  push(Str $key, HashRef $val) : Int
-
-The push method should push data onto the bottom of a list in the datastore.
-
-=over 4
-
-=item push example #1
-
-  # given: synopsis
-
-  $store->push('collection', { status => 'ok' });
+  $store->lpush('collection', { status => '0' });
 
 =back
 
@@ -348,6 +323,55 @@ The recv method should fetch and return data from the datastore by its key.
 
 =cut
 
+=head2 rpull
+
+  rpull(Str $key) : Maybe[HashRef]
+
+The rpull method should pop data off of the bottom of a list in the datastore.
+
+=over 4
+
+=item rpull example #1
+
+  # given: synopsis
+
+  $store->rpull('collection');
+
+=back
+
+=over 4
+
+=item rpull example #2
+
+  # given: synopsis
+
+  # $store->rpush('collection', { status => 1 });
+  # $store->rpush('collection', { status => 2 });
+
+  $store->rpull('collection');
+
+=back
+
+=cut
+
+=head2 rpush
+
+  rpush(Str $key, HashRef $val) : Int
+
+The rpush method should push data onto the bottom of a list in the datastore.
+
+=over 4
+
+=item rpush example #1
+
+  # given: synopsis
+
+  $store->rpush('collection', { status => 'ok' });
+
+=back
+
+=cut
+
 =head2 send
 
   send(Str $key, HashRef $val) : Str
@@ -389,7 +413,7 @@ The size method should return the size of a list in the datastore.
 
   # given: synopsis
 
-  # $store->push('collection', { status => 'ok' });
+  # $store->rpush('collection', { status => 'ok' });
 
   my $size = $store->size('collection');
 
@@ -420,7 +444,7 @@ position in the list.
 
   # given: synopsis
 
-  # $store->push('collection', { status => 'ok' });
+  # $store->rpush('collection', { status => 'ok' });
 
   my $model = $store->slot('collection', 0);
 
@@ -460,7 +484,7 @@ datastore.
 
   # given: synopsis
 
-  # $store->push('collection', { status => 'ok' });
+  # $store->rpush('collection', { status => 'ok' });
 
   $store->test('collection');
 
